====
List
====

The following methods are available under the `expr.list` attribute.

.. currentmodule:: polars
.. autosummary::
   :toctree: api/
   :template: autosummary/accessor_method.rst

    Expr.list.all
    Expr.list.any
    Expr.list.arg_max
    Expr.list.arg_min
    Expr.list.concat
    Expr.list.contains
    Expr.list.count_match
    Expr.list.diff
    Expr.list.difference
    Expr.list.eval
    Expr.list.explode
    Expr.list.first
    Expr.list.get
    Expr.list.head
    Expr.list.intersection
    Expr.list.join
    Expr.list.last
    Expr.list.lengths
    Expr.list.max
    Expr.list.mean
    Expr.list.min
    Expr.list.reverse
    Expr.list.shift
    Expr.list.slice
    Expr.list.sort
    Expr.list.sum
    Expr.list.tail
    Expr.list.take
    Expr.list.to_struct
    Expr.list.union
    Expr.list.unique
